==> Newsletter-1.0.0.zip: lang/ext/ru_RU.php <==
<?php
$lang['friendlyname'] = 'E-mail рассылки';
$lang['moddescription'] = 'Позволяет создавать e-mail рассылки пользователям CMS и пользователям модуля "FrontEndUsers"';
$lang['postinstall'] = 'Модуль "E-mail рассылки" успешно установлен!';
$lang['postuninstall'] = 'Модуль "E-mail рассылки" успешно удалён!';
$lang['uninstallconfirm'] = 'Вы уверены, что Вы хотите удалть модуль "E-mail рассылки"?';
$lang['installed'] = 'Модуль "E-mail рассылки" - версии %s установлен.';
$lang['uninstalled'] = 'Модуль "E-mail рассылки" удалён.';
$lang['help'] = file_get_contents(dirname(__FILE__).'/../../help/ru_RU.hlp');

#Module texts
$lang['Mailings'] = 'Рассылки';
$lang['EmailTemplates'] = 'E-mail шаблоны';
$lang['FEUSettings'] = 'Настройки модуля "FrontEndUsers"';
$lang['LastMailingDate'] = 'Дата последней рассылки';
$lang['SenderEmail'] = 'E-mail отправителя';
$lang['Subject'] = 'Тема';
$lang['HTMLTemplate'] = 'HTML шаблон';
$lang['TXTTemplate'] = 'Текстовый(альтернативный) шаблон';
$lang['TemplateAllowedTagsText'] = 'Вы можете использовать следующие теги в шаблоне';
$lang['EmailText'] = 'Текст рассылки';
$lang['SetActive'] = 'Сделать активным';
$lang['SetInactive'] = 'Сделать неактивным';
$lang['AddMailing'] = 'Создать новую рассылку';
$lang['HTMLContent'] = 'HTML содержание';
$lang['TXTContent'] = 'Текстовые(альтернативное) содержание';
$lang['NoTemplate'] = 'Без шаблона';
$lang['SendMails'] = 'Отправить e-mail\'ы';
$lang['CMSUsers'] = 'Пользователи CMS';
$lang['FrontendUsers'] = 'Пользователи модуля "FrontEndUsers"';
$lang['TotalToSend'] = 'Всего к отправке';
$lang['Sent'] = 'Отправлено';
$lang['ErrorSending'] = 'Ошибки при отправке';
$lang['ErrorsWhileSending'] = 'При отправке некоторых e-mail\'ов произошли ошибки';
$lang['SendingMessage'] = 'Пожалуйсте не закрывайте и не обновляейте окно, пока процесс отправки не будет завершён.';
$lang['Done'] = 'Выполнено!';
$lang['FEUModuleEmailField'] = 'Брать E-mail пользователя из следующего поля';
$lang['FEUModuleNoProperty'] = 'Не используется';
$lang['FEUModuleNoEmailProperty'] = 'Поле логина';
$lang['FEUModuleFirstNameField'] = 'Имя в теге {USERNAME}';
$lang['FEUModuleLastNameField'] = 'Фамилия в теге {USERNAME}';

#Module errors texts
$lang['ErrTemplateNameEmpty'] = 'Поле "Имя" не может быть пустым!';
$lang['ErrMailingNameEmpty'] = 'Поле "Имя" не может быть пустым!';
$lang['ErrSenderEmailEmpty'] = 'Поле "E-mail отправителя" не может быть пустым!';
$lang['ErrSubjectEmpty'] = 'Поле "Тема" не может быть пустым!';

#Module event logs
$lang['EventLogMailingRemoved'] = 'Рассылка удалена.';
$lang['EventLogTemplateRemoved'] = 'Шаблон удалён.';
$lang['EventLogMailingSaved'] = 'Рассылка сохранена.';
$lang['EventLogTemplateSaved'] = 'Шаблон сохранён.';
$lang['EventLogFEUSettingsSaved'] = 'Настройки модуля "FronEndUsers" сохранены.';
$lang['EventLogMailingCommited'] = 'Совершена рассылка.';
?>

==> Newsletter-1.1.0.zip: lang/ext/ru_RU.php <==
<?php
$lang['friendlyname'] = 'E-mail рассылки';
$lang['moddescription'] = 'Позволяет создавать e-mail рассылки пользователям CMS и пользователям модуля "FrontEndUsers"';
$lang['postinstall'] = 'Модуль "E-mail рассылки" успешно установлен!';
$lang['postuninstall'] = 'Модуль "E-mail рассылки" успешно удалён!';
$lang['uninstallconfirm'] = 'Вы уверены, что Вы хотите удалть модуль "E-mail рассылки"?';
$lang['installed'] = 'Модуль "E-mail рассылки" - версии %s установлен.';
$lang['uninstalled'] = 'Модуль "E-mail рассылки" удалён.';
$lang['help'] = file_get_contents(dirname(__FILE__).'/../../help/ru_RU.hlp');

#Module texts
$lang['Mailings'] = 'Рассылки';
$lang['EmailTemplates'] = 'E-mail шаблоны';
$lang['FEUSettings'] = 'Настройки модуля "FrontEndUsers"';
$lang['LastMailingDate'] = 'Дата последней рассылки';
$lang['SenderEmail'] = 'E-mail отправителя';
$lang['Subject'] = 'Тема';
$lang['HTMLTemplate'] = 'HTML шаблон';
$lang['TXTTemplate'] = 'Текстовый(альтернативный) шаблон';
$lang['TemplateAllowedTagsText'] = 'Вы можете использовать следующие теги в шаблоне';
$lang['EmailText'] = 'Текст рассылки';
$lang['SetActive'] = 'Сделать активным';
$lang['SetInactive'] = 'Сделать неактивным';
$lang['AddMailing'] = 'Создать новую рассылку';
$lang['HTMLContent'] = 'HTML содержание';
$lang['TXTContent'] = 'Текстовые(альтернативное) содержание';
$lang['NoTemplate'] = 'Без шаблона';
$lang['SendMails'] = 'Отправить e-mail\'ы';
$lang['CMSUsers'] = 'Пользователи CMS';
$lang['FrontendUsers'] = 'Пользователи модуля "FrontEndUsers"';
$lang['TotalToSend'] = 'Всего к отправке';
$lang['Sent'] = 'Отправлено';
$lang['ErrorSending'] = 'Ошибки при отправке';
$lang['ErrorsWhileSending'] = 'При отправке некоторых e-mail\'ов произошли ошибки';
$lang['SendingMessage'] = 'Пожалуйсте не закрывайте и не обновляейте окно, пока процесс отправки не будет завершён.';
$lang['Done'] = 'Выполнено!';
$lang['FEUModuleEmailField'] = 'Брать E-mail пользователя из следующего поля';
$lang['FEUModuleNoProperty'] = 'Не используется';
$lang['FEUModuleNoEmailProperty'] = 'Поле логина';
$lang['FEUModuleFirstNameField'] = 'Имя в теге {USERNAME}';
$lang['FEUModuleLastNameField'] = 'Фамилия в теге {USERNAME}';

#Module errors texts
$lang['ErrTemplateNameEmpty'] = 'Поле "Имя" не может быть пустым!';
$lang['ErrMailingNameEmpty'] = 'Поле "Имя" не может быть пустым!';
$lang['ErrSenderEmailEmpty'] = 'Поле "E-mail отправителя" не может быть пустым!';
$lang['ErrSubjectEmpty'] = 'Поле "Тема" не может быть пустым!';

#Module premissions
$lang['PermissionsShowModule'] = 'Модуль "E-mail рассылки": Показывать модуль';
$lang['PermissionsViewMailings'] = 'Модуль "E-mail рассылки": Видеть рассылки';
$lang['PermissionsCreateMailings'] = 'Модуль "E-mail рассылки": Создавать рассылки';
$lang['PermissionsDeleteMailings'] = 'Модуль "E-mail рассылки": Удалять рассылки';
$lang['PermissionsProcessMailings'] = 'Модуль "E-mail рассылки": Отправлять e-mail\'ы';
$lang['PermissionsViewTemplates'] = 'Модуль "E-mail рассылки": Видеть шаблоны';
$lang['PermissionsCreateTemplates'] = 'Модуль "E-mail рассылки": Создавать шаблоны';
$lang['PermissionsDeleteTemplates'] = 'Модуль "E-mail рассылки": Удалять шаблоны';
$lang['PermissionsChangeModuleSettings'] = 'Модуль "E-mail рассылки": Менять настройки модуля';
$lang['NoPermissions'] = 'К сожалению, у Вас нету достаточных прав чтобы увидеть данный модуль. Обратитесь к администратору CMS.';

#Module event logs
$lang['EventLogMailingRemoved'] = 'Рассылка удалена.';
$lang['EventLogTemplateRemoved'] = 'Шаблон удалён.';
$lang['EventLogMailingSaved'] = 'Рассылка сохранена.';
$lang['EventLogTemplateSaved'] = 'Шаблон сохранён.';
$lang['EventLogFEUSettingsSaved'] = 'Настройки модуля "FronEndUsers" сохранены.';
$lang['EventLogMailingCommited'] = 'Совершена рассылка.';
?>
